@@ -49,6 +49,9 @@ public:
     /* returns track position (elapsed time) in seconds */
     int trackPosition() const;
 
+    /* returns track position (elapsed time) in milliseconds */
+    int trackPositionMs() const;
+
     /**
      * Returns the current track that is loaded into the engine.
      * @return a Meta::TrackPtr which is either the track, or empty if phonon
@@ -152,6 +155,7 @@ private:
     QPointer<Meta::MultiSourceCapability> m_multiSource;
     bool m_playWhenFetched;
     QTimer* m_fadeoutTimer;
+    int m_volume;
 
     QMutex m_mutex;
 };
