@@ -19,11 +19,12 @@
 
 #include "SafeFileSaver.h"
 
-#include "taglib/fileref.h"
-#include "taglib/id3v2tag.h"
-#include "taglib/mpegfile.h"
-#include "taglib/tfile.h"
-#include "taglib/uniquefileidentifierframe.h"
+//Taglib
+#include <fileref.h>
+#include <id3v2tag.h>
+#include <mpegfile.h>
+#include <tfile.h>
+#include <uniquefileidentifierframe.h>
 
 #include <KAboutData>
 #include <KCmdLineArgs>
@@ -74,7 +75,7 @@ int main( int argc, char *argv[] )
     options.add("+file(s)", ki18n( "Files/Directories to tag" ) );
     options.add("d").add("delete", ki18n( "Delete AFT IDs from the files") );
     options.add("n").add("newid", ki18n( "Generate a new ID even if an up-to-date one exists" ) );
-    options.add("q").add("quiet", ki18n( "No prompts -- Indicates you agree to the terms of use!" ) );
+    options.add("q").add("quiet", ki18n( "No prompts -- Indicates you agree to the terms of use." ) );
     options.add("r").add("recurse", ki18n( "Recursively process files and directories" ) );
     options.add("V").add("verbose", ki18n( "More verbose output" ) );
     KCmdLineArgs::addCmdLineOptions( options );
@@ -109,7 +110,7 @@ int main( int argc, char *argv[] )
         std::cin >> response;
         cin.get();
 
-        if( response != "y" && response != "Y" )
+        if( response != "y" && response != "Y" && QString::fromUtf8(response.c_str()) != i18nc("translate this according to what you translated in TERMS OF USE sentence", "y") && QString::fromUtf8(response.c_str()) != i18nc("translate this according to what you translated in TERMS OF USE sentence", "Y"))
         {
             qDebug() << "INFO: Terms not accepted; exiting...";
             return 1;
