@@ -81,6 +81,10 @@ class ServiceBrowser : public KVBox
          */
         void showService( const QString &name );
 
+        QString activeServiceName();
+        QString activeServiceFilter();
+        QList<int> activeServiceLevels();
+
     public slots:
         /**
          * Add a service.
@@ -94,6 +98,11 @@ class ServiceBrowser : public KVBox
          */
         void setScriptableServiceManager( ScriptableServiceManager *scriptableServiceManager );
 
+        /**
+         * Slot called when the active service should be hidden the service selection list shown again.
+         */
+        void home();
+
     private:
         /**
          * Private constructor ( Singleton pattern )
@@ -128,11 +137,6 @@ class ServiceBrowser : public KVBox
          */
         void serviceActivated( const QModelIndex &index );
 
-        /**
-         * Slot called when the active service should be hidden the service selection list shown again.
-         */
-        void home();
-
         void slotSetFilterTimeout();
         void slotFilterNow();
 
