@@ -23,14 +23,12 @@
 #include "App.h"
 #include "Debug.h"
 #include "ServiceListModel.h"
-#include "SvgTinter.h"
 #include "services/ServiceBase.h"
 
 #include <QApplication>
 #include <QFontMetrics>
 #include <QIcon>
 #include <QPainter>
-#include <QPixmapCache>
 
 
 ServiceListDelegate::ServiceListDelegate( QTreeView *view )
@@ -118,9 +116,4 @@ ServiceListDelegate::sizeHint( const QStyleOptionViewItem & option, const QModel
     return QSize( width, height );
 }
 
-void
-ServiceListDelegate::paletteChange()
-{
-    The::svgHandler()->reTint();
-}
 
