@@ -272,7 +272,7 @@ DaapTrack::inCollection() const
     return true;
 }
 
-Collection*
+Amarok::Collection*
 DaapTrack::collection() const
 {
     return m_collection;
@@ -430,9 +430,9 @@ DaapAlbum::canUpdateImage() const
 }
 
 void
-DaapAlbum::setImage( const QImage &image )
+DaapAlbum::setImage( const QPixmap &pixmap )
 {
-    Q_UNUSED(image);
+    Q_UNUSED(pixmap);
     //TODO
 }
 
