@@ -1,8 +1,5 @@
-/* 
-   Mostly taken from Daap code:
-   Copyright (C) 2006 Ian Monroe <ian@monroe.nu>
-   Copyright (C) 2006 Seb Ruiz <ruiz@kde.org>  
-   Copyright (C) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>
+/*
+   Copyright (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,9 +22,9 @@
 #include "Collection.h"
 #include "MemoryCollection.h"
 
-#include <QtGlobal>
+#include <KIcon>
 
-class MediaDeviceCollection;
+#include <QtGlobal>
 
 class MediaDeviceCollectionFactory : public Amarok::CollectionFactory
 {
@@ -36,13 +33,15 @@ class MediaDeviceCollectionFactory : public Amarok::CollectionFactory
         MediaDeviceCollectionFactory();
         virtual ~MediaDeviceCollectionFactory();
 
-        virtual void init();
+        virtual void init() = 0;
 
     private:
 
     private slots:
-    
-    private:
+        virtual void deviceDetected() = 0;
+        virtual void deviceRemoved( const QString &udi ) = 0;
+        virtual void slotCollectionReady() = 0;
+        virtual void slotCollectionDisconnected( const QString & udi ) = 0;
 
 };
 
@@ -51,25 +50,23 @@ class MediaDeviceCollection : public Amarok::Collection, public MemoryCollection
     Q_OBJECT
     public:
 
-        MediaDeviceCollection( const QString &mountPoint);
-        virtual ~MediaDeviceCollection();
+        void copyTrackListToDevice( const Meta::TrackList tracklist );
 
         virtual void startFullScan();
         virtual QueryMaker* queryMaker();
 
         virtual QString collectionId() const;
-        virtual QString prettyName() const;        
+        virtual QString prettyName() const;
+        virtual KIcon icon() const { return KIcon("drive-removable-media-usb"); }
 
     signals:
         void collectionReady();
 
     public slots:
+        virtual void deleteTracksSlot( Meta::TrackList tracklist );
 
-    private slots:
-
-    private:
-
-
+    protected:
+        MediaDevice::MediaDeviceHandler *m_handler;
 };
 
 #endif
