@@ -16,10 +16,12 @@
 #define AMAROK_WIKIPEDIA_ENGINE
 
 #include "ContextObserver.h"
+#include "meta/Meta.h"
 
 #include <context/DataEngine.h>
 
 #include <KIO/Job>
+#include <QLocale>
 
 /**
     This class provide Wikipedia data for use in Context applets. 
@@ -31,7 +33,7 @@ NOTE: The QVariant data is structured like this:
 
 using namespace Context;
 
-class WikipediaEngine : public DataEngine, public ContextObserver
+class WikipediaEngine : public DataEngine, public ContextObserver, Meta::Observer
 {
     Q_OBJECT
     Q_PROPERTY( QString selectionType READ selection WRITE setSelection )
@@ -45,11 +47,15 @@ public:
     // reimplemented from Context::Observer
     virtual void message( const ContextState& state );
 
+    // reimplemented from Meta::Observer
+    using Observer::metadataChanged;
+    void metadataChanged( Meta::TrackPtr track );
+
     void setSelection( const QString& selection ) { m_currentSelection = selection; }
     QString selection() { return m_currentSelection; }
     
 protected:
-    bool sourceRequested( const QString& name );
+    bool sourceRequestEvent( const QString& name );
     
 private slots:
     void wikiResult( KJob* );
@@ -60,19 +66,22 @@ private:
     QString wikiArtistPostfix();
     QString wikiAlbumPostfix();
     QString wikiTrackPostfix();
+    QString wikiSiteUrl();
     QString wikiUrl( const QString& item ) const;
     QString wikiLocale() const;
     
     void reloadWikipedia();
     
     KJob* m_wikiJob;
+
+    Meta::TrackPtr m_currentTrack;
         
     QString m_currentSelection;
     QString m_wiki;
     QString m_wikiCurrentEntry;
     QString m_wikiCurrentUrl;
     QString m_wikiLanguages;
-    QString m_wikiLocale;
+    QLocale m_wikiLang;
     // stores what features are enabled
     bool m_requested;
     QStringList m_sources;
