@@ -1,7 +1,7 @@
 /******************************************************************************
  * Copyright (c) 2004 Mark Kretschmann <kretschmann@kde.org>                  *
  *           (c) 2004 Stefan Bogner <bochi@online.ms>                         *
- *           (c) 2007 Dan Meltzer <hydrogen@notyetimplemented.com>            *
+ *           (c) 2007 Dan Meltzer <parallelgrapefruit@gmail.com>            *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License as             *
@@ -16,7 +16,7 @@
  * You should have received a copy of the GNU General Public License          *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
  ******************************************************************************/
- 
+
 #ifndef AMAROK_COVERFETCHER_H
 #define AMAROK_COVERFETCHER_H
 
@@ -35,9 +35,10 @@ class KLineEdit;
 class CoverLabel : public QLabel
 {
     public:
-    explicit CoverLabel ( QWidget * parent, Qt::WindowFlags f = 0 );
+    explicit CoverLabel( QWidget * parent, Qt::WindowFlags f = 0 );
 
-    void setInformation( const QString artist, const QString album ) {
+    void setInformation( const QString artist, const QString album )
+    {
         m_artist = artist;
         m_album = album;
     }
@@ -63,8 +64,7 @@ class CoverFetcher : public QObject
 
 public:
     AMAROK_EXPORT static CoverFetcher* instance();
-
-   ~CoverFetcher();
+    AMAROK_EXPORT static void destroy();
 
     /// allow the user to edit the query?
     void setUserCanEditQuery( bool b ) { m_userCanEditQuery = b; }
@@ -74,7 +74,7 @@ public:
 
     QString amazonURL() const { return m_amazonURL; }
     QString asin() const { return m_asin; }
-    QImage image() const { return m_image; }
+    QPixmap image() const { return m_pixmap; }
 
     AMAROK_EXPORT void queueAlbum( Meta::AlbumPtr album );
     AMAROK_EXPORT void queueAlbums( Meta::AlbumList albums );
@@ -92,8 +92,10 @@ private slots:
     void changeLocale( int id );
 
 private:
-    friend class CoverFetcherSingleton;
+    static CoverFetcher* s_instance;
     CoverFetcher();
+    ~CoverFetcher();
+
     void parseItemNode( const QDomNode &node );
 
     Meta::AlbumList m_albums;
@@ -104,7 +106,7 @@ private:
     bool    m_userCanEditQuery;
     QString m_userQuery; /// the query from the query edit dialog
     QString m_xml;
-    QImage  m_image;
+    QPixmap  m_pixmap;
     QString m_amazonURL;
     QString m_asin;
     int     m_size;
