@@ -22,40 +22,37 @@
 #ifndef AMAROK_PLAYLISTWIDGET_H
 #define AMAROK_PLAYLISTWIDGET_H
 
-#include "widgets/StackedWidget.h"
-
+#include "view/listview/PrettyListView.h"
 
 #include <KVBox>
 
+#include <QComboBox>
 #include <QLabel>
+
 class QWidget;
 class ProgressiveSearchWidget;
 
 namespace Playlist
 {
-
-class Widget : public KVBox
-{
-    Q_OBJECT
-
-public:
-    Widget( QWidget* parent );
-    QWidget* currentView()
+    class Widget : public KVBox
     {
-        return m_playlistView;
-    }
+        Q_OBJECT
 
-public slots:
-    void switchView();
+        public:
+            Widget( QWidget* parent );
+            PrettyListView* currentView() { return m_playlistView; }
 
-protected:
-    QSize sizeHint() const;
+        public slots:
+            void sort( int field );
 
-private:
-    Amarok::StackedWidget *m_stackedWidget;
-    QWidget* m_playlistView;
-    ProgressiveSearchWidget * m_searchWidget;
-};
+        protected:
+            QSize sizeHint() const;
+
+        private:
+            PrettyListView* m_playlistView;
+            ProgressiveSearchWidget * m_searchWidget;
+            QComboBox * m_sortBox;
+    };
 }
 
 #endif
