@@ -131,6 +131,7 @@ ServiceTrack::ServiceTrack( const QString & name )
     , CustomActionsProvider()
     , SourceInfoProvider()
     , CurrentTrackActionsProvider()
+    , BookmarkThisProvider()
     , m_genre( 0 )
     , m_composer( 0 )
     , m_year( 0 )
@@ -154,6 +155,7 @@ ServiceTrack::ServiceTrack( const QStringList & resultRow )
     , CustomActionsProvider()
     , SourceInfoProvider()
     , CurrentTrackActionsProvider()
+    , BookmarkThisProvider()
     , m_genre( 0 )
     , m_composer( 0 )
     , m_year( 0 )
@@ -316,7 +318,7 @@ ServiceTrack::composer() const
 YearPtr
 ServiceTrack::year() const
 {
-    if( !m_year == 0 )
+    if( m_year )
         return YearPtr::staticCast( m_year );
     else
         return Meta::YearPtr( new DefaultYear() );
@@ -468,7 +470,7 @@ ServiceTrack::type() const
 }
 
 void
-ServiceTrack::setAlbum( AlbumPtr album )
+ServiceTrack::setAlbumPtr( AlbumPtr album )
 {
     m_album = album;
 }
@@ -522,6 +524,7 @@ ServiceArtist::ServiceArtist( const QString & name )
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_id( 0 )
     , m_name( name )
     , m_description( 0 )
@@ -535,6 +538,7 @@ ServiceArtist::ServiceArtist(const QStringList & resultRow)
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_tracks()
 {
 
@@ -626,6 +630,7 @@ ServiceAlbum::ServiceAlbum( const QString & name )
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_id( 0 )
     , m_name( name )
     , m_tracks()
@@ -642,6 +647,7 @@ ServiceAlbum::ServiceAlbum(const QStringList & resultRow)
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_id( resultRow[0].toInt() )
     , m_name( resultRow[1] )
     , m_isCompilation( false )
@@ -778,6 +784,7 @@ ServiceGenre::ServiceGenre( const QString &name )
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_id( 0 )
     , m_albumId( 0 )
     , m_name( name )
@@ -791,6 +798,7 @@ ServiceGenre::ServiceGenre(const QStringList & row)
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_id( 0 )
     , m_albumId( 0 )
     , m_name( row[1] )
@@ -866,6 +874,7 @@ ServiceComposer::ServiceComposer( const QString &name )
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_name( name )
     , m_tracks()
 {
@@ -915,6 +924,7 @@ ServiceYear::ServiceYear( const QString &name )
     , ServiceDisplayInfoProvider()
     , CustomActionsProvider()
     , SourceInfoProvider()
+    , BookmarkThisProvider()
     , m_name( name )
     , m_tracks()
 {
