@@ -22,7 +22,6 @@
 
 #include "Debug.h"
 
-#include <QToolTip>
 
 PopupWidget::PopupWidget( QWidget * anchor, const QString &name )
         : KVBox( The::mainWindow() )
@@ -46,7 +45,9 @@ PopupWidget::PopupWidget( QWidget * anchor, const QString &name )
 }
 
 PopupWidget::~PopupWidget()
-{}
+{
+    DEBUG_BLOCK
+}
 
 void PopupWidget::reposition()
 {
